@@ -1,5 +1,6 @@
 import io
 import time
+import string
 import inspect
 import requests
 import pandas as pd
@@ -295,10 +296,12 @@ class DatabaseManagement(Base):
         
         table_meta, schema = self.get_table_schema(table_id=table_id)
         con_str = self._get_connection_str(con_id=table_meta['database'])
-        meta = self._create_pandas_meta(meta=meta, pk_column=pk_column)
-        return dd.read_sql_query(sql=query_function(), con=con_str, index_col=pk_column, meta=meta)
-    
-    def _read_sql_query_no_meta(self, table_id=None, query_function=None, pk_column=None):
-        table_meta, schema = self.get_table_schema(table_id=table_id)
-        con_str = self._get_connection_str(con_id=table_meta['database'])
-        return dd.read_sql_query(sql=query_function(), con=con_str, index_col=pk_column)
\ No newline at end of file
+        df_meta = self._create_pandas_meta(meta=meta, pk_column=pk_column)
+        if meta[pk_column] == 'str':
+            possible_divisions = list('0123456789' + string.ascii_lowercase + string.ascii_uppercase)
+            possible_divisions.sort()
+            ddf = dd.read_sql_query(sql=query_function(), con=con_str, index_col=pk_column, meta=df_meta, divisions=possible_divisions)
+        else:
+            ddf = dd.read_sql_query(sql=query_function(), con=con_str, index_col=pk_column, meta=df_meta, bytes_per_chunk="100 MB")
+        
+        return ddf
\ No newline at end of file
